@@ -14,11 +14,13 @@ from gi.repository import GdkPixbuf
 from gi.repository import GLib
 from gi.repository import GObject
 from gi.repository import Gtk
+from gi.repository import Notify
 
 from kuwo import Config
 # ~/.config/kuwo and ~/.cache/kuwo need to be created at first time
 Config.check_first()
 _ = Config._
+Notify.init(Config.APPNAME)
 from kuwo.log import logger
 from kuwo import Widgets
 from kuwo.Artists import Artists
@@ -52,15 +54,17 @@ class App:
         self.app.connect('activate', self.on_app_activate)
         self.app.connect('shutdown', self.on_app_shutdown)
 
-        self.conf = Config.load_conf()
-        self.theme, self.theme_path = Config.load_theme()
-
     def on_app_startup(self, app):
+        self.conf = Config.load_conf()
+        self.icon_theme = Gtk.IconTheme.get_default()
+        self.icon_theme.append_search_path(Config.ICON_PATH)
+
+        GLib.set_application_name(Config.APPNAME)
         self.window = Gtk.ApplicationWindow(application=app)
         self.window.set_default_size(*self.conf['window-size'])
         self.window.set_title(Config.APPNAME)
+        self.window.set_default_icon_name(Config.NAME)
         self.window.props.hide_titlebar_when_maximized = True
-        self.window.set_icon(self.theme['app-logo'])
         app.add_window(self.window)
         self.window.connect('check-resize', self.on_main_window_resized)
         self.window.connect('delete-event', self.on_main_window_deleted)
@@ -74,6 +78,8 @@ class App:
         self.window.add(box)
 
         self.osdlrc = OSDLrc(self)
+        self.notify = None
+        self.init_notify()
 
         self.player = Player(self)
         box.pack_start(self.player, False, False, 0)
@@ -282,8 +288,7 @@ class App:
             self.status_icon.set_menu(menu)
             self.status_icon.set_status(AppIndicator.IndicatorStatus.ACTIVE)
         else: 
-            self.status_icon = Gtk.StatusIcon()
-            self.status_icon.set_from_pixbuf(self.theme['app-logo'])
+            self.status_icon = Gtk.StatusIcon.new_from_icon_name(Config.NAME)
             # left click
             self.status_icon.connect('activate', on_status_icon_activate)
             # right click
@@ -335,3 +340,22 @@ class App:
             GLib.timeout_add(100, self.player.playbin.expose)
             #GLib.idle_add(self.player.playbin.expose)
             self.notebook.set_show_tabs(False)
+
+    def init_notify(self):
+        try:
+            self.notify = Notify.Notification.new(Config.APPNAME, '',
+                                                  Config.NAME)
+        except Exception:
+            logger.warn('App.init_notify: %s' % traceback.format_exc())
+            self.notify = None
+
+    # Open API
+    def toast(self, text):
+        '''在用户界面显示一个消息通知.
+
+        可以使用系统提供的Notification工具, 也可以在窗口的最下方滚动弹出
+        这个消息
+        '''
+        if self.notify:
+            self.notify.update(Config.APPNAME, text, Config.NAME)
+            self.notify.show()
